/*
 *  LibRoadnav
 *  Point.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// This is rather similar to wxRealPoint.
///
/// Stores a 2D point. Can also calculate the angle from the origin to 
/// the point, distance to origin, and other goodies.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef POINT_H
#define POINT_H

#include "Serialization.h"

#if defined _MSC_VER
#define POSITION_FORMAT_1 wxT("ddd.dddddd h")
#define POSITION_FORMAT_2 wxT("ddd mm.mmm' h")
#define POSITION_FORMAT_3 wxT("ddd mm' ss.s\" h")
#else
#define POSITION_FORMAT_1 wxT("ddd.ddddd h")
#define POSITION_FORMAT_2 wxT("ddd mm.mmm' h")
#define POSITION_FORMAT_3 wxT("ddd mm' ss.s'\" h")
#endif

//////////////////////////////////////////////////////////////////////////////
/// \brief This is rather similar to wxRealPoint. Stores a 2D floating point
/// coordinate.
///
/// Can also calculate the angle from the origin to 
/// the point, distance to origin, and other goodies.
///
//////////////////////////////////////////////////////////////////////////////
class Point : public Serialization
{
	public:
		Point();
		Point(double fLong, double fLat);
		Point(wxInt32 lLong, wxInt32 lLat, int iIgnore);

		virtual ~Point();

		void Set(double fLong, double fLat);
		void SetRaw(wxInt32 lLong, wxInt32 lLat);
		
		void SetInvalid();
		
		double GetLong() const;
		double GetLat() const;
		wxInt32 GetLongRaw() const;
		wxInt32 GetLatRaw() const;
		
		void SetLong(double fLong);
		void SetLat(double fLat);
		void SetLongRaw(wxInt32 lLong);
		void SetLatRaw(wxInt32 lLat);
		
		bool IsValid() const;
	
		wxString ToString();
		int FromString(wxString strDesc);

		wxString FormatPoint();
		void ParsePoint(wxString strDesc);

		static void SetPointFormat(wxString strFormat);

		double abs();
		double angle();

		bool operator <(const Point & x) const;
		bool operator >(const Point & x) const;
		bool operator <=(const Point & x) const;
		bool operator >=(const Point & x) const;
		bool operator ==(const Point & x) const;
		bool operator !=(const Point & x) const;
		Point operator +(const Point & x) const;
		Point operator -(const Point & x) const;
		Point operator /(double x) const;
		Point operator *(double x) const;

		virtual void Serialize(FILE * hFile, bool bSave, void * pvArg);

	private:
		static wxString m_strPointFormat;

		/// Longitutde of this point
		wxInt32 m_lLong;
	
		/// Latitude of this point
		wxInt32 m_lLat;

};

#endif
