/*
 *  LibRoadnav
 *  ProgressDialog.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// This file contains the ProgressDialog class, which
/// shows a dialog box containing a gauge and text control.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef PROGRESSDIALOG_H
#define PROGRESSDIALOG_H

#include <wx/datetime.h>

//////////////////////////////////////////////////////////////////////////////
///
/// \brief A simple progress dialog, containing a gauge and text control
///
//////////////////////////////////////////////////////////////////////////////
class ProgressDialog : public wxDialog
{
	public:
		ProgressDialog(wxWindow *parent, wxString strTitle, int iMax);
		void SetProgress(int iPosition);
		void SetLabel(wxString strLabel);
	
	private:
		/// Label appearing above the gauage
		wxStaticText * m_ctlLabel;
	
		/// Gauge control itself
		wxGauge * m_ctlGauge;

		/// Current position of progress bar
		int m_iPosition;
		
		/// Maximum position of progress bar
		int m_iRange;
		
		/// Time progress bar was last allowed to be redrawn
		wxDateTime m_tLastUpdate;

		DECLARE_EVENT_TABLE()
};

#endif
