/*
 *  LibRoadnav
 *  Serialization.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Serialization base class. Derivative classes can be easily loaded
/// from/saved to a file.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef SERIALIZATION_H
#define SERIALIZATION_H

//////////////////////////////////////////////////////////////////////////////
/// \brief Serialization base class. Derivative classes can be easily loaded
/// from/saved to a file.
///
//////////////////////////////////////////////////////////////////////////////
class Serialization
{
	public:
		virtual ~Serialization();

		void SerializeItem(FILE * hFile, bool bSave, bool * i);
		void SerializeItem(FILE * hFile, bool bSave, double * i);
		void SerializeItem(FILE * hFile, bool bSave, wxUint32 * i);
		void SerializeItem(FILE * hFile, bool bSave, wxUint16 * i);
		void SerializeItem(FILE * hFile, bool bSave, wxInt32 * i);
		void SerializeItem(FILE * hFile, bool bSave, wxInt16 * i);
		void SerializeItem(FILE * hFile, bool bSave, char * i, int nLen);

		void SerializeItem(FILE * hFile, bool bSave, Serialization * i, void * pvArg);

		virtual void Serialize(FILE * hFile, bool bSave, void * pvArg) = 0;
};

#endif
